@@ -29,17 +29,6 @@ typedef enum {
   WP_LINK_STATE_ACTIVE = 4,     /*!< the link is active */
 } WpLinkState;
 
-/*!
- * \brief An extension of WpProxyFeatures
- * \ingroup wplink
- *
- * \since 0.4.11
- */
-typedef enum { /*< flags >*/
-  /*! waits until the state of the link is >= PAUSED */
-  WP_LINK_FEATURE_ESTABLISHED = (WP_PROXY_FEATURE_CUSTOM_START << 0),
-} WpLinkFeatures;
-
 /*!
  * \brief The WpLink GType
  * \ingroup wplink
